package seminar7;

public class Employee {
    public static final double STANDARD_EMPLOYEE_SALARY = 20000.0;
    public static final double PT_HOUR_SALARY = 150.0;
    public static final double VOLUNTEER_SALARY = 2000.0;
    
    final static int EMPLOYEE_TYPE_STANDARD = 1;
    final static int EMPLOYEE_TYPE_PT = 2;
    final static int EMPLOYEE_TYPE_VOLUNTEER = 3;
    
    final private String name;
    final private int type;
    final private double hours;

    public Employee(String name, int type, double hours) {
        assert type == EMPLOYEE_TYPE_STANDARD ||
                type == EMPLOYEE_TYPE_PT ||
                type == EMPLOYEE_TYPE_VOLUNTEER;
        this.name = name;
        this.type = type;
        this.hours = hours;
    }
    
    public Employee(String name, int type) {
        this(name, type, 0);
    }
    
    public double salary() {
        
        switch(type) {
            case EMPLOYEE_TYPE_STANDARD:
                return STANDARD_EMPLOYEE_SALARY;
            case EMPLOYEE_TYPE_PT:
                return PT_HOUR_SALARY * hours;
            case EMPLOYEE_TYPE_VOLUNTEER:
                return VOLUNTEER_SALARY;
            default:
                throw new IllegalStateException("Unknown employee type: " + type);
        }
    }
    
    public String payout() {
        if(type == EMPLOYEE_TYPE_VOLUNTEER) {
            return "cash";
        }
        return "bank transfer";
    }

    @Override
    public String toString() {
        String s = name + " ";
        switch(type) {
           case EMPLOYEE_TYPE_STANDARD:
                s += "STANDARD ";
                break;
            case EMPLOYEE_TYPE_PT:
                s += "PART TIME ";
                break;
            case EMPLOYEE_TYPE_VOLUNTEER:
                s += "VOLUNTEER ";
                break;
            default:
                throw new IllegalStateException("Unknown employee type: " + type);
        }
        s += salary() + " paid by: " + payout();
        return s;
    }
}
